---
name: Bug report
about: Create a report to help us improve
---

**Describe the bug**

A clear and concise description of what the bug is.

**To reproduce**

Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**

A clear and concise description of what you expected to happen.

**Screenshots**

If applicable, add screenshots to help explain your problem.

**Versions**

 - OS: [e.g. Windows 10]
 - Browser: [e.g. chrome, safari]
 - Nengo GUI: [e.g. 0.3.0, latest master]
 - Other: [e.g. Nengo core v2.8.0]

**Additional context**

Add any other context about the problem here.
